# Easy PIL
A library to make common tasks of Pillow easy.

# Usage
[Examples](https://github.com/shahriyardx/easy-pil/tree/master/examples)

[Tutorials](https://youtube.com/playlist?list=PLb_oBhGqAlbT4yVqV0TSXggA8b0lZhGhn)